summaryrefslogtreecommitdiff
path: root/readme-debian.el
diff options
context:
space:
mode:
authorpsg <>2003-09-02 14:10:58 +0000
committerpsg <>2003-09-02 14:10:58 +0000
commitf0a3cae2e516fe5a4c3b652675ae838f45abe919 (patch)
tree0cb0bc93b0cce65dd8b2caab8a86f49b95646295 /readme-debian.el
parentf09fd5e74faf898b73b0b8536b2cded3e44b73b7 (diff)
Updated to V0.0.20030825
Diffstat (limited to 'readme-debian.el')
-rw-r--r--readme-debian.el7
1 files changed, 4 insertions, 3 deletions
diff --git a/readme-debian.el b/readme-debian.el
index 94b3c47..ab948cf 100644
--- a/readme-debian.el
+++ b/readme-debian.el
@@ -85,7 +85,7 @@ will be updated.
(kill-all-local-variables)
(setq major-mode 'readme-debian-mode)
(setq mode-name "README.Debian")
- (mapcar 'make-local-variable '(font-lock-defaults write-file-hooks))
+ (make-local-variable 'font-lock-defaults)
(use-local-map readme-debian-mode-map)
(set-syntax-table readme-debian-mode-syntax-table)
(setq font-lock-defaults
@@ -94,8 +94,9 @@ will be updated.
nil ;; case-fold?
nil ;; Local syntax table.
))
- ;; add timestamp update func to write-file-hook
- (add-to-list 'write-file-hooks 'readme-debian-update-timestamp)
+ ;; add timestamp update func to write-contents-hooks
+ (add-hook 'write-contents-hooks 'readme-debian-update-timestamp
+ nil t)
(run-hooks 'readme-debian-mode-hook))
(run-hooks 'readme-debian-mode-load-hook)